@@ -10,7 +10,7 @@ class TalkValidation(Validation):
 	@property
 	def jsonSchema(self) -> dict:
 		schema = self._dirPath / 'schemas/talk-schema.json'
-		return json.loads(schema.read_text())
+		return json.loads(schema.read_text(encoding='utf-8'))
 
 
 	@property
